@@ -13,6 +13,7 @@
 #  29-Jul-2014 jdw WARNING -- Handling of variant seqeuences is incomplete --
 #  02-Sep-2020 zf  added a work-around for isoforms sequence.
 #  29-Dec-2020 zf  added getMultipleResultDict()
+#  25-Sep-2022 zf  removed the work-around for isoforms sequence. It seems that the regular dbfetch tool can handle isoforms sequence now.
 ##
 
 __author__ = "Zukang Feng"
@@ -68,7 +69,7 @@ class FetchUnpXml:
         self.__searchIdList = []
         self.__variantD = {}
         #
-        self.__isoformIdList = []
+#       self.__isoformIdList = []
         #
         cI = ConfigInfo()
         self.__forcefallback = cI.get("FETCH_UNP_FORCE_FALLBACK", None)
@@ -92,18 +93,21 @@ class FetchUnpXml:
             self.__multipleResult = {}
             self.__dataList = []
             self.__idList = []
-            self.__isoformIdList = []
+#           self.__isoformIdList = []
 
             for accId in idList:
-                splitList = accId.split("-")
-                if len(splitList) == 2:
-                    if splitList[0] not in self.__isoformIdList:
-                        self.__isoformIdList.append(splitList[0])
-                    #
-                else:
-                    if accId not in self.__idList:
-                        self.__idList.append(accId)
-                    #
+#               splitList = accId.split("-")
+#               if len(splitList) == 2:
+#                   if accId not in self.__isoformIdList:
+#                       self.__isoformIdList.append(accId)
+#                   #
+#               else:
+#                   if accId not in self.__idList:
+#                       self.__idList.append(accId)
+#                   #
+#               #
+                if accId not in self.__idList:
+                    self.__idList.append(accId)
                 #
             #
 
@@ -115,7 +119,7 @@ class FetchUnpXml:
                 self.__lfh.write("+FetchUnpXml.fetchList() search   list %s\n" % self.__searchIdList)
                 self.__lfh.write("+FetchUnpXml.fetchList() variants      %s\n" % self.__variantD.items())
             #
-            if (num == 0) and (not self.__isoformIdList):
+            if (num == 0): # and (not self.__isoformIdList):
                 return False
             #
             if num:
@@ -142,12 +146,12 @@ class FetchUnpXml:
                     #
                 #
             #
-            for accId in self.__isoformIdList:
-                xmlText = self.__RequestIsoformsUnpXml(accId)
-                if xmlText:
-                    self.__dataList.append(xmlText)
-                #
-            #
+#           for accId in self.__isoformIdList:
+#               xmlText = self.__RequestIsoformsUnpXml(accId)
+#               if xmlText:
+#                   self.__dataList.append(xmlText)
+#               #
+#           #
             if len(self.__dataList) > 0:
                 ok = self.__ParseUnpXmlData()
             else:
@@ -231,7 +235,7 @@ class FetchUnpXml:
             params["style"] = "raw"
             # params['Retrieve'] = 'Retrieve'
             logger.debug("Request %s with data %s", self._baseUrl, params)
-            reqH = requests.post(self._baseUrl, data=params, verify=False)
+            reqH = requests.post(self._baseUrl, data=params, verify=False, timeout=30)
             reqH.raise_for_status()
         else:
             params = {}
@@ -240,7 +244,7 @@ class FetchUnpXml:
 
             # Need to do this as UNP service will not take POST - so force GET
             logger.debug("Request with data %s", params)
-            reqH = requests.get(self._baseUrlUnp, params=params, headers={"Accept": "application/xml"}, verify=False)
+            reqH = requests.get(self._baseUrlUnp, params=params, headers={"Accept": "application/xml"}, verify=False, timeout=30)
             reqH.raise_for_status()
         #
         # data = reqH.read()
@@ -251,7 +255,7 @@ class FetchUnpXml:
         """Using URL https://www.ebi.ac.uk/proteins/api/proteins/{accession}/isoforms"""
         isoformUrl = self._baseUrlUnp + "/" + accId + "/isoforms"
         params = {}
-        reqH = requests.get(isoformUrl, params=params, headers={"Accept": "application/xml"}, verify=False)
+        reqH = requests.get(isoformUrl, params=params, headers={"Accept": "application/xml"}, verify=False, timeout=30)
         reqH.raise_for_status()
         data = reqH.text
         if data.find("errorMessages") >= 0:
